==> SnappEmailApiClient-0.3.20.zip: SnappEmailApiClient-0.3.20/snapp_email/datacontract/content_type_to_class_mapping.py <==
content_type_to_class_mapping = {
    'application/vnd.4thoffice.appointment.response-v5.18+json': 'AppointmentResponse_22',
    'application/vnd.4thoffice.actionable.resource-v5.17+json': 'ActionableResource_21',
    'application/vnd.4thoffice.assistant.insight-5.18+json': 'AssistantInsight_22',
    'application/vnd.4thoffice.access.token.info-5.3+json': 'AccessTokenInfo_17',
    'application/vnd.4thoffice.document-v5.8+json': 'Document_18',
    'application/vnd.4thoffice.gmail.sync.info-5.2+json': 'GMailSyncInfo_16',
    'application/vnd.marg.bcsocial.error.log.client-2.6+json': 'ClientErrorLog_4',
    'application/vnd.4thoffice.discussion.card.combined-5.15+json': 'DiscussionCardCombined_20',
    'application/vnd.4thoffice.reminder-v5.15+json': 'Reminder_20',
    'application/vnd.4thoffice.discussion.card-5.18+json': 'DiscussionCard_22',
    'application/vnd.4thoffice.actionable.resource.overview-v5.18+json': 'ActionableResourceOverview_22',
    'application/vnd.marg.bcsocial.access.token.info-3.6+json': 'AccessTokenInfo_13',
    'application/vnd.4thoffice.actionable.resource.list.page-v5.18+json': 'ListOfActionableResourcesPage_22',
    'application/vnd.marg.bcsocial.logon.user.mobile-v2.6+json': 'LogOnUserMobile_4',
    'application/vnd.4thoffice.user.settings.gmail.sync-4.0+json': 'UserSettingsGMailSync_14',
    'application/vnd.4thoffice.location.list.page-v5.12+json': 'ListOfLocationsPage_19',
    'application/vnd.4thoffice.post.preview-5.15+json': 'PostPreview_20',
    'application/vnd.4thoffice.notification.list.page-v5.18+json': 'ListOfNotificationsPage_22',
    'application/vnd.4thoffice.search.results-v5.15+json': 'SearchResults_20',
    'application/vnd.4thoffice.document-v4.0+json': 'Document_14',
    'application/vnd.4thoffice.search.group-v5.8+json': 'SearchGroup_18',
    'application/vnd.4thoffice.appointment.list.page-v5.15+json': 'AppointmentListPage_20',
    'application/vnd.4thoffice.reminder.followup-v5.15+json': 'ReminderFollowup_20',
    'application/vnd.4thoffice.badge-5.0+json': 'BadgeBase_15',
    'application/vnd.marg.bcsocial.document.thumbnail-v2.6+json': 'DocumentThumbnail_4',
    'application/vnd.marg.bcsocial.thumbnail.text.map.page-v5.12+json': 'ThumbnailTextMapPage_19',
    'application/vnd.4thoffice.user.settings.notification-5.15+json': 'UserSettingsNotification_20',
    'application/vnd.4thoffice.board.list-v5.0+json': 'ListOfBoards_15',
    'application/vnd.4thoffice.signature.image-5.15+json': 'SignatureImage_20',
    'application/vnd.4thoffice.invite-5.15+json': 'Invite_20',
    'application/vnd.4thoffice.reminder.appointment-v5.15+json': 'ReminderAppointment_20',
    'application/vnd.4thoffice.search.results.grouped.page-v5.8+json': 'SearchResultsGroupedPage_18',
    'application/vnd.4thoffice.drive-4.0+json': 'Drive_14',
    'application/vnd.4thoffice.discussion.card.combined-5.18+json': 'DiscussionCardCombined_22',
    'text/json': 'ListOfPostsPage_22',
    'application/vnd.4thoffice.action.finish.workflow-v5.8+json': 'ActionFinishWorkflow_18',
    'application/vnd.4thoffice.user.settings.gmail.sync-5.2+json': 'UserSettingsGMailSync_16',
    'application/vnd.4thoffice.appointment-v5.18+json': 'Appointment_22',
    'application/vnd.4thoffice.board.list.page-v5.0+json': 'ListOfBoardsPage_15',
    'application/vnd.4thoffice.action.delete.pin.notification-v5.8+json': 'ActionDeletePinNotification_18',
    'application/vnd.marg.bcsocial.document.thumbnail.page.info-v3.6+json': 'DocumentThumbnailPageInfo_13',
    'application/vnd.4thoffice.actionable.resource.overview-v5.15+json': 'ActionableResourceOverview_20',
    'application/vnd.4thoffice.post-5.8+json': 'Post_18',
    'application/vnd.4thoffice.menu.item-v5.17+json': 'MenuItem_21',
    'application/vnd.4thoffice.post-5.18+json': 'Post_22',
    'application/vnd.4thoffice.group.notification.settings-5.3+json': 'GroupNotificationSettings_17',
    'application/vnd.4thoffice.action.delete.reminder-v5.8+json': 'ActionDeleteReminder_18',
    'application/vnd.4thoffice.notification.action.list.updated.last-v5.8+json': 'NotificationActionListUpdatedLast_18',
    'application/vnd.4thoffice.board.base-5.18+json': 'BoardBase_22',
    'application/vnd.4thoffice.action.delete.question-v5.8+json': 'ActionDeleteQuestion_18',
    'application/vnd.4thoffice.invoice-5.18+json': 'Invoice_22',
    'application/vnd.4thoffice.signature-5.15+json': 'Signature_20',
    'application/vnd.marg.bcsocial.api.index-v1.9+json': 'ApiIndex_1',
    'application/vnd.4thoffice.signature.list.page-5.15+json': 'ListOfSignaturesPage_20',
    'application/vnd.4thoffice.board.group-5.18+json': 'BoardGroup_22',
    'application/vnd.4thoffice.actionable.resource.overview-v5.17+json': 'ActionableResourceOverview_21',
    'application/vnd.4thoffice.client.event.log.list.page-5.0+json': 'ListOfClientEventLogsPage_15',
    'application/vnd.4thoffice.feed-5.18+json': 'Feed_22',
    'application/vnd.4thoffice.board.personal-5.15+json': 'BoardPersonal_20',
    'application/vnd.4thoffice.post.pinnedto.list-v5.18+json': 'PostPinnedToList_22',
    'application/vnd.marg.bcsocial.document.thumbnail.info-v3.6+json': 'DocumentThumbnailInfo_13',
    'application/vnd.marg.bcsocial.campaign-3.5+json': 'Campaign_12',
    'application/vnd.4thoffice.board.name-5.18+json': 'BoardName_22',
    'application/vnd.4thoffice.document.pinnedto.list-v5.0+json': 'DocumentPinnedToList_15',
    'application/vnd.4thoffice.analysis.post-v5.18+json': 'AnalysisPost_22',
    'application/vnd.marg.bcsocial.result.localized-v2.6+json': 'LocalizedResult_1',
    'application/vnd.4thoffice.board.list.page-v5.15+json': 'ListOfBoardsPage_20',
    'application/vnd.4thoffice.reminder.mention-v5.15+json': 'ReminderMention_20',
    'application/vnd.4thoffice.user.settings-4.0+json': 'UserSettings_14',
    'application/vnd.4thoffice.stream.chat-5.18+json': 'StreamChat_22',
    'application/vnd.4thoffice.post.body-5.18+json': 'PostBody_22',
    'application/vnd.4thoffice.feed-5.12+json': 'Feed_19',
    'application/vnd.4thoffice.reminder.question-v5.15+json': 'ReminderQuestion_20',
    'application/vnd.4thoffice.board.personal-5.17+json': 'BoardPersonal_21',
    'application/vnd.4thoffice.board-5.0+json': 'BoardBase_15',
    'application/vnd.4thoffice.action.delete.mention-v5.8+json': 'ActionDeleteMention_18',
    'application/vnd.4thoffice.post.flag.managed.by.assistant-v5.15+json': 'PostFlagManagedByAssistant_20',
    'application/vnd.4thoffice.actionable.resource.list.page-v5.15+json': 'ListOfActionableResourcesPage_20',
    'application/vnd.4thoffice.search.results-v5.18+json': 'SearchResults_22',
    'application/vnd.4thoffice.client.event.log.list-5.0+json': 'ListOfClientEventLogs_15',
    'application/vnd.4thoffice.stream-5.3+json': 'StreamBase_17',
    'application/vnd.4thoffice.stream.cards-5.18+json': 'StreamCards_22',
    'application/vnd.4thoffice.actionable.resource.list.page-v5.17+json': 'ListOfActionableResourcesPage_21',
    'application/vnd.4thoffice.actionable.resource.availability-v5.15+json': 'ActionableResourceAvailability_20',
    'application/vnd.4thoffice.board.avatar-5.18+json': 'BoardAvatar_22',
    'application/vnd.4thoffice.notification.list.page-v5.15+json': 'ListOfNotificationsPage_20',
    'application/vnd.4thoffice.reminder.base-v5.15+json': 'ReminderBase_20',
    'application/vnd.4thoffice.agenda.list.page-v5.18+json': 'ListOfAgendaPage_22',
    'application/vnd.4thoffice.action.set.reminder-v5.8+json': 'ActionSetReminder_18',
    'application/vnd.4thoffice.notification.assistant.nudge-v5.15+json': 'NotificationAssistantNudge_20',
    'application/vnd.4thoffice.board.personal-5.18+json': 'BoardPersonal_22',
    'application/vnd.4thoffice.microsoft.exchange.sync.info-5.2+json': 'MicrosoftExchangeSyncInfo_16',
    'application/vnd.4thoffice.post.action.list-5.18+json': 'PostActionList_22',
    'application/vnd.4thoffice.agenda.summary-v5.18+json': 'AgendaSummary_22',
    'application/vnd.4thoffice.group.leave-5.18+json': 'GroupLeave_22',
    'application/vnd.4thoffice.stream.group-5.3+json': 'StreamGroup_17',
    'application/vnd.4thoffice.action.delete-v5.8+json': 'ActionDelete_18',
    'application/vnd.4thoffice.localization.language.list-4.0+json': 'ListOfLanguagesPage_14',
    'application/vnd.4thoffice.notification.reminder.list.updated-v5.18+json': 'NotificationReminderListUpdated_22',
    'application/vnd.4thoffice.stream.visibility-5.18+json': 'StreamVisibility_22',
    'application/vnd.4thoffice.actionable.resource-v5.15+json': 'ActionableResource_20',
    'application/vnd.4thoffice.reminder.base-v5.17+json': 'Reminder_21',
    'application/vnd.4thoffice.document.share.list-v4.0+json': 'DocumentShareList_14',
    'application/vnd.4thoffice.group.avatar-5.3+json': 'GroupAvatar_17',
    'application/vnd.4thoffice.user.avatar-5.3+json': 'UserAvatar_17',
    'application/vnd.4thoffice.post.assistant-5.18+json': 'PostAssistant_22',
    'application/vnd.marg.bcsocial.access.token.info.user-3.6+json': 'AccessTokenInfoUser_13',
    'application/vnd.4thoffice.post.pinnedto.list-v5.15+json': 'PostPinnedToList_20',
    'application/vnd.4thoffice.stream.name-5.18+json': 'StreamName_22',
    'application/vnd.4thoffice.notification.action.list.updated-v5.8+json': 'NotificationActionListUpdated_18',
    'application/vnd.4thoffice.post-5.15+json': 'Post_20',
    'application/vnd.4thoffice.board.list.page-v5.18+json': 'ListOfBoardsPage_22',
    'application/vnd.4thoffice.post.board.link-v5.18+json': 'PostBoardLink_22',
    'application/vnd.marg.bcsocial.result-v1.9+json': 'Result_1',
    'application/vnd.4thoffice.stream.base-5.18+json': 'StreamBase_22',
    'application/vnd.4thoffice.reminder.calendar-v5.15+json': 'ReminderCalendar_20',
    'application/vnd.4thoffice.reminder.base-v5.18+json': 'Reminder_22',
    'application/vnd.4thoffice.localization.region.list-4.0+json': 'ListOfRegionsPage_14',
    'application/vnd.4thoffice.action.hide.stream-v5.8+json': 'ActionHideStream_18',
    'application/vnd.4thoffice.logon.user-v4.0+json': 'LogOnUser_14',
    'application/vnd.4thoffice.appointment.response-v5.15+json': 'AppointmentResponse_20',
    'application/vnd.4thoffice.post.unread-5.18+json': 'PostUnread_22',
    'application/vnd.4thoffice.stream.group-5.18+json': 'StreamGroup_22',
    'application/vnd.4thoffice.discussion.separator.unread-5.8+json': 'DiscussionSeparatorUnread_18',
    'application/vnd.4thoffice.group-5.3+json': 'Group_17',
    'application/vnd.4thoffice.menu.item-v5.15+json': 'MenuItem_20',
    'application/vnd.4thoffice.localization.time.zone.list-4.0+json': 'ListOfTimeZonesPage_14',
    'application/vnd.4thoffice.file-v4.0+json': 'File_14',
    'application/vnd.4thoffice.notification.list.page-v5.0+json': 'ListOfNotificationsPage_15',
    'application/vnd.4thoffice.stream.user-5.3+json': 'StreamUser_17',
    'application/vnd.4thoffice.board.personal-5.0+json': 'BoardPersonal_15',
    'application/vnd.4thoffice.user.settings.location.tracking-5.15+json': 'UserSettingsLocationTracking_20',
    'application/vnd.4thoffice.board.list.page-v5.17+json': 'ListOfBoardsPage_21',
    'application/vnd.4thoffice.discussion.card-5.15+json': 'DiscussionCard_20',
    'application/vnd.4thoffice.user-4.0+json': 'User_14',
    'application/vnd.4thoffice.feed-5.15+json': 'Feed_20',
    'application/vnd.4thoffice.user.settings.microsoft.exchange.sync-5.2+json': 'UserSettingsMicrosoftExchangeSync_16',
    'application/vnd.4thoffice.actionable.resource-v5.18+json': 'ActionableResource_22',
    'application/vnd.4thoffice.post.pinnedto.list-v5.17+json': 'PostPinnedToList_21',
    'application/vnd.4thoffice.access.token-4.0+json': 'AccessToken_14',
    'application/vnd.4thoffice.stream.user-5.18+json': 'StreamUser_22',
    'application/vnd.4thoffice.appointment-v5.15+json': 'Appointment_20',
}

==> SnappEmailApiClient-0.3.22.zip: SnappEmailApiClient-0.3.22/snapp_email/datacontract/content_type_to_class_mapping.py <==
content_type_to_class_mapping = {
    'application/vnd.4thoffice.badge-5.0+json': 'BadgeBase_15',
    'application/vnd.marg.bcsocial.document.thumbnail-v2.6+json': 'DocumentThumbnail_4',
    'application/vnd.4thoffice.user.settings.gmail.sync-4.0+json': 'UserSettingsGMailSync_14',
    'application/vnd.4thoffice.search.results-v5.15+json': 'SearchResults_20',
    'application/vnd.4thoffice.drive-4.0+json': 'Drive_14',
    'application/vnd.4thoffice.board.group-5.18+json': 'BoardGroup_22',
    'application/vnd.4thoffice.notification.list.page-v5.18+json': 'ListOfNotificationsPage_22',
    'application/vnd.marg.bcsocial.document.thumbnail.info-v3.6+json': 'DocumentThumbnailInfo_13',
    'application/vnd.4thoffice.reminder.followup-v5.15+json': 'ReminderFollowup_20',
    'application/vnd.4thoffice.reminder.calendar-v5.15+json': 'ReminderCalendar_20',
    'application/vnd.4thoffice.post.action.list-5.18+json': 'PostActionList_22',
    'application/vnd.marg.bcsocial.access.token.info-3.6+json': 'AccessTokenInfo_13',
    'application/vnd.marg.bcsocial.thumbnail.text.map.page-v5.12+json': 'ThumbnailTextMapPage_19',
    'application/vnd.4thoffice.post.pinnedto.list-v5.18+json': 'PostPinnedToList_22',
    'application/vnd.4thoffice.invoice-5.18+json': 'Invoice_22',
    'application/vnd.4thoffice.client.event.log.list.page-5.0+json': 'ListOfClientEventLogsPage_15',
    'application/vnd.4thoffice.post.unread-5.18+json': 'PostUnread_22',
    'application/vnd.marg.bcsocial.logon.user.mobile-v2.6+json': 'LogOnUserMobile_4',
    'application/vnd.4thoffice.discussion.card-5.15+json': 'DiscussionCard_20',
    'application/vnd.4thoffice.signature.list.page-5.15+json': 'ListOfSignaturesPage_20',
    'application/vnd.4thoffice.stream.assistant-5.18+json': 'StreamAssistant_22',
    'application/vnd.4thoffice.action.hide.stream-v5.8+json': 'ActionHideStream_18',
    'application/vnd.4thoffice.board.list.page-v5.15+json': 'ListOfBoardsPage_20',
    'application/vnd.4thoffice.post-5.18+json': 'Post_22',
    'application/vnd.4thoffice.post.board.link-v5.18+json': 'PostBoardLink_22',
    'application/vnd.4thoffice.board.list-v5.0+json': 'ListOfBoards_15',
    'application/vnd.4thoffice.feed-5.18+json': 'Feed_22',
    'application/vnd.4thoffice.board.personal-5.18+json': 'BoardPersonal_22',
    'application/vnd.4thoffice.menu.item-v5.15+json': 'MenuItem_20',
    'application/vnd.4thoffice.appointment-v5.15+json': 'Appointment_20',
    'application/vnd.4thoffice.feed-5.12+json': 'Feed_19',
    'application/vnd.4thoffice.stream.base-5.18+json': 'StreamBase_22',
    'application/vnd.4thoffice.discussion.card.combined-5.15+json': 'DiscussionCardCombined_20',
    'application/vnd.4thoffice.notification.action.list.updated-v5.8+json': 'NotificationActionListUpdated_18',
    'application/vnd.marg.bcsocial.access.token.info.user-3.6+json': 'AccessTokenInfoUser_13',
    'application/vnd.4thoffice.board.personal-5.17+json': 'BoardPersonal_21',
    'application/vnd.4thoffice.board.list.page-v5.0+json': 'ListOfBoardsPage_15',
    'application/vnd.4thoffice.discussion.separator.unread-5.8+json': 'DiscussionSeparatorUnread_18',
    'application/vnd.4thoffice.board.name-5.18+json': 'BoardName_22',
    'application/vnd.4thoffice.stream.name-5.18+json': 'StreamName_22',
    'application/vnd.4thoffice.reminder-v5.15+json': 'Reminder_20',
    'application/vnd.4thoffice.localization.language.list-4.0+json': 'ListOfLanguagesPage_14',
    'application/vnd.4thoffice.action.delete.reminder-v5.8+json': 'ActionDeleteReminder_18',
    'application/vnd.4thoffice.stream.user-5.3+json': 'StreamUser_17',
    'application/vnd.4thoffice.action.set.reminder-v5.8+json': 'ActionSetReminder_18',
    'application/vnd.marg.bcsocial.result.localized-v2.6+json': 'LocalizedResult_1',
    'application/vnd.4thoffice.stream.cards-5.18+json': 'StreamCards_22',
    'application/vnd.4thoffice.actionable.resource-v5.17+json': 'ActionableResource_21',
    'application/vnd.4thoffice.board.personal-5.15+json': 'BoardPersonal_20',
    'application/vnd.4thoffice.appointment-v5.18+json': 'Appointment_22',
    'application/vnd.4thoffice.assistant.insight-5.18+json': 'AssistantInsight_22',
    'application/vnd.4thoffice.board-5.0+json': 'BoardBase_15',
    'application/vnd.4thoffice.post-5.15+json': 'Post_20',
    'application/vnd.4thoffice.agenda.summary-v5.18+json': 'AgendaSummary_22',
    'application/vnd.4thoffice.group-5.3+json': 'Group_17',
    'application/vnd.4thoffice.post.flag.managed.by.assistant-v5.15+json': 'PostFlagManagedByAssistant_20',
    'application/vnd.4thoffice.action.delete-v5.8+json': 'ActionDelete_18',
    'application/vnd.4thoffice.stream.group-5.3+json': 'StreamGroup_17',
    'application/vnd.4thoffice.group.leave-5.18+json': 'GroupLeave_22',
    'application/vnd.4thoffice.stream.group-5.18+json': 'StreamGroup_22',
    'application/vnd.4thoffice.access.token-4.0+json': 'AccessToken_14',
    'application/vnd.4thoffice.actionable.resource.overview-v5.18+json': 'ActionableResourceOverview_22',
    'application/vnd.4thoffice.discussion.card-5.18+json': 'DiscussionCard_22',
    'application/vnd.4thoffice.location.list.page-v5.12+json': 'ListOfLocationsPage_19',
    'application/vnd.4thoffice.gmail.sync.info-5.2+json': 'GMailSyncInfo_16',
    'application/vnd.4thoffice.reminder.base-v5.17+json': 'Reminder_21',
    'application/vnd.4thoffice.discussion.card.combined-5.18+json': 'DiscussionCardCombined_22',
    'application/vnd.4thoffice.menu.item-v5.17+json': 'MenuItem_21',
    'application/vnd.4thoffice.board.list.page-v5.18+json': 'ListOfBoardsPage_22',
    'application/vnd.4thoffice.post.list.page-5.18+json': 'ListOfPostsPage_22',
    'application/vnd.4thoffice.user.settings.gmail.sync-5.2+json': 'UserSettingsGMailSync_16',
    'application/vnd.4thoffice.notification.reminder.list.updated-v5.18+json': 'NotificationReminderListUpdated_22',
    'application/vnd.4thoffice.document.share.list-v4.0+json': 'DocumentShareList_14',
    'application/vnd.4thoffice.microsoft.exchange.sync.info-5.2+json': 'MicrosoftExchangeSyncInfo_16',
    'application/vnd.4thoffice.actionable.resource-v5.15+json': 'ActionableResource_20',
    'application/vnd.4thoffice.post.body-5.18+json': 'PostBody_22',
    'application/vnd.4thoffice.post.preview-5.15+json': 'PostPreview_20',
    'application/vnd.4thoffice.board.base-5.18+json': 'BoardBase_22',
    'application/vnd.4thoffice.access.token.info-5.3+json': 'AccessTokenInfo_17',
    'application/vnd.4thoffice.notification.list.page-v5.0+json': 'ListOfNotificationsPage_15',
    'application/vnd.4thoffice.actionable.resource.list.page-v5.15+json': 'ListOfActionableResourcesPage_20',
    'application/vnd.4thoffice.action.delete.mention-v5.8+json': 'ActionDeleteMention_18',
    'application/vnd.4thoffice.reminder.question-v5.15+json': 'ReminderQuestion_20',
    'application/vnd.4thoffice.user-4.0+json': 'User_14',
    'application/vnd.4thoffice.post.pinnedto.list-v5.15+json': 'PostPinnedToList_20',
    'application/vnd.4thoffice.stream-5.3+json': 'StreamBase_17',
    'application/vnd.4thoffice.post-5.8+json': 'Post_18',
    'application/vnd.4thoffice.logon.user-v4.0+json': 'LogOnUser_14',
    'application/vnd.4thoffice.search.results-v5.18+json': 'SearchResults_22',
    'application/vnd.4thoffice.invite-5.15+json': 'Invite_20',
    'application/vnd.4thoffice.reminder.base-v5.18+json': 'Reminder_22',
    'application/vnd.4thoffice.user.settings.microsoft.exchange.sync-5.2+json': 'UserSettingsMicrosoftExchangeSync_16',
    'application/vnd.marg.bcsocial.result-v1.9+json': 'Result_1',
    'application/vnd.4thoffice.group.avatar-5.3+json': 'GroupAvatar_17',
    'application/vnd.4thoffice.actionable.resource.overview-v5.15+json': 'ActionableResourceOverview_20',
    'application/vnd.4thoffice.signature.image-5.15+json': 'SignatureImage_20',
    'application/vnd.4thoffice.search.results.grouped.page-v5.8+json': 'SearchResultsGroupedPage_18',
    'application/vnd.4thoffice.client.event.log.list-5.0+json': 'ListOfClientEventLogs_15',
    'application/vnd.4thoffice.document-v4.0+json': 'Document_14',
    'application/vnd.4thoffice.board.personal-5.0+json': 'BoardPersonal_15',
    'text/json': 'ActionNextStep_18',
    'application/vnd.4thoffice.signature-5.15+json': 'Signature_20',
    'application/vnd.marg.bcsocial.document.thumbnail.page.info-v3.6+json': 'DocumentThumbnailPageInfo_13',
    'application/vnd.4thoffice.localization.region.list-4.0+json': 'ListOfRegionsPage_14',
    'application/vnd.4thoffice.appointment.response-v5.18+json': 'AppointmentResponse_22',
    'application/vnd.4thoffice.notification.list.page-v5.15+json': 'ListOfNotificationsPage_20',
    'application/vnd.4thoffice.stream.chat-5.18+json': 'StreamChat_22',
    'application/vnd.4thoffice.user.settings.location.tracking-5.15+json': 'UserSettingsLocationTracking_20',
    'application/vnd.4thoffice.file-v4.0+json': 'File_14',
    'application/vnd.4thoffice.document-v5.8+json': 'Document_18',
    'application/vnd.4thoffice.agenda.list.page-v5.18+json': 'ListOfAgendaPage_22',
    'application/vnd.4thoffice.feed-5.15+json': 'Feed_20',
    'application/vnd.4thoffice.reminder.appointment-v5.15+json': 'ReminderAppointment_20',
    'application/vnd.4thoffice.appointment.response-v5.15+json': 'AppointmentResponse_20',
    'application/vnd.4thoffice.reminder.base-v5.15+json': 'ReminderBase_20',
    'application/vnd.4thoffice.user.settings-4.0+json': 'UserSettings_14',
    'application/vnd.4thoffice.post.pinnedto.list-v5.17+json': 'PostPinnedToList_21',
    'application/vnd.4thoffice.search.group-v5.8+json': 'SearchGroup_18',
    'application/vnd.4thoffice.document.pinnedto.list-v5.0+json': 'DocumentPinnedToList_15',
    'application/vnd.4thoffice.group.notification.settings-5.3+json': 'GroupNotificationSettings_17',
    'application/vnd.4thoffice.action.delete.pin.notification-v5.8+json': 'ActionDeletePinNotification_18',
    'application/vnd.marg.bcsocial.campaign-3.5+json': 'Campaign_12',
    'application/vnd.4thoffice.board.avatar-5.18+json': 'BoardAvatar_22',
    'application/vnd.4thoffice.stream.visibility-5.18+json': 'StreamVisibility_22',
    'application/vnd.4thoffice.stream.user-5.18+json': 'StreamUser_22',
    'application/vnd.4thoffice.actionable.resource.list.page-v5.17+json': 'ListOfActionableResourcesPage_21',
    'application/vnd.4thoffice.notification.action.list.updated.last-v5.8+json': 'NotificationActionListUpdatedLast_18',
    'application/vnd.marg.bcsocial.api.index-v1.9+json': 'ApiIndex_1',
    'application/vnd.4thoffice.user.settings.notification-5.15+json': 'UserSettingsNotification_20',
    'application/vnd.4thoffice.post.assistant-5.18+json': 'PostAssistant_22',
    'application/vnd.marg.bcsocial.error.log.client-2.6+json': 'ClientErrorLog_4',
    'application/vnd.4thoffice.actionable.resource.overview-v5.17+json': 'ActionableResourceOverview_21',
    'application/vnd.4thoffice.reminder.mention-v5.15+json': 'ReminderMention_20',
    'application/vnd.4thoffice.board.list.page-v5.17+json': 'ListOfBoardsPage_21',
    'application/vnd.4thoffice.action.finish.workflow-v5.8+json': 'ActionFinishWorkflow_18',
    'application/vnd.4thoffice.user.avatar-5.3+json': 'UserAvatar_17',
    'application/vnd.4thoffice.action.delete.question-v5.8+json': 'ActionDeleteQuestion_18',
    'application/vnd.4thoffice.actionable.resource.list.page-v5.18+json': 'ListOfActionableResourcesPage_22',
    'application/vnd.4thoffice.notification.assistant.nudge-v5.15+json': 'NotificationAssistantNudge_20',
    'application/vnd.4thoffice.localization.time.zone.list-4.0+json': 'ListOfTimeZonesPage_14',
    'application/vnd.4thoffice.actionable.resource.availability-v5.15+json': 'ActionableResourceAvailability_20',
    'application/vnd.4thoffice.appointment.list.page-v5.15+json': 'AppointmentListPage_20',
    'application/vnd.4thoffice.actionable.resource-v5.18+json': 'ActionableResource_22',
}
